BirdSexRatio: Sex Ratios in Birds

Description Usage Format Source Examples

Description

Correlation coefficient of sex ratio in bird offspring.

Usage

1

Format

A data frame with 15 observations of one variable

corr.coeff

correlation coefficient of sex ratio in bird offspring

West, S.A. and B.C. Sheldon. 2002. Constraints in the evolution of sex ratio adjustment. Science 295: 1695-1688.

Examples

1
2
3
data(BirdSexRatio)
histogram(~corr.coeff, BirdSexRatio, n = 10,
  xlab = "Correlation Coefficient")

Example output

Loading required package: nlme
Loading required package: lattice
Loading required package: grid
Loading required package: mosaic
Registered S3 method overwritten by 'mosaic':
  method                           from   
  fortify.SpatialPolygonsDataFrame ggplot2

The 'mosaic' package masks several functions from core packages in order to add 
additional features.  The original behavior of these functions should not be affected by this.

Attaching package: ‘mosaic’

The following objects are masked from ‘package:dplyr’:

    count, do, tally

The following object is masked from ‘package:Matrix’:

    mean

The following object is masked from ‘package:ggplot2’:

    stat

The following objects are masked from ‘package:stats’:

    binom.test, cor, cor.test, cov, fivenum, IQR, median, prop.test,
    quantile, sd, t.test, var

The following objects are masked from ‘package:base’:

    max, mean, min, prod, range, sample, sum

abd documentation built on May 2, 2019, 4:46 p.m.